@@ -53,9 +53,9 @@ if os.path.exists( tmpdir ):
 print 'Info: Create directories'
 
 for kit_dir in [
-    tmpdir,
-    os.path.join( tmpdir, '%s' % pkg_filename),
-    ]:
+        tmpdir,
+        os.path.join( tmpdir, '%s' % pkg_filename),
+        ]:
     if not os.path.exists( kit_dir ):
         os.makedirs( kit_dir )
 
@@ -76,6 +76,7 @@ for cp_src, cp_dst_dir_fmt in [
 print 'Info: Export WorkBench_files'
 if os.path.exists( '../../Docs/WorkBench_files/.svn' ):
     os_system( 'svn export ../../Docs/WorkBench_files tmp/%s/WorkBench_files' % pkg_filename )
+
 else:
     os_system( 'mkdir tmp/%s/WorkBench_files' % pkg_filename )
     os_system( 'cp ../../Docs/WorkBench_files/* tmp/%s/WorkBench_files' % pkg_filename )
@@ -102,6 +103,7 @@ print 'Info: python bundle'
 os_system( '${PYTHON} -u make_wb_bundle.py tmp/%s' % pkg_filename)
 
 print 'Info: Make Disk Image'
-os_system( 'hdiutil create -srcfolder tmp/%s tmp/tmp.dmg' % pkg_filename )
+# if hdiutil exists with a -5341 error make the size bigger
+os_system( 'hdiutil create -size 200m -srcfolder tmp/%s tmp/tmp.dmg' % pkg_filename )
 os_system( 'hdiutil convert tmp/tmp.dmg -format UDZO -imagekey zlib-level=9 ' 
         '-o tmp/%s.dmg' % pkg_filename )
