@@ -1,10 +1,10 @@
-#!/bin/sh
+#!/bin/bash
 export PYSVN_WORKBENCH_STDOUT_LOG=$(tty)
 if [ "$PYTHONPATH" = "" ]
 then
-	export PYTHONPATH=${WORKDIR}/Source
+	export PYTHONPATH=${BUILDER_TOP_DIR}/Source
 else
-	export PYTHONPATH=${WORKDIR}/Source:$PYTHONPATH
+	export PYTHONPATH=${BUILDER_TOP_DIR}/Source:$PYTHONPATH
 fi
 
 PYTHON=${PYTHON:-python}
