@@ -3,7 +3,7 @@
  Copyright (c) 2003-2011 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
- which you should have received as part of this distribution.
+ which you should have received as part of this distributio.
 
  ====================================================================
 
@@ -23,17 +23,44 @@ import wx
 import wx.lib
 import wx.lib.newevent
 
+def _print( msg ):
+    print( msg )
+
+def _showCallers( depth, printFunc ):
+    stack = inspect.stack()
+    for index in range( 1, depth+1 ):
+        if index >= len(stack):
+            break
+
+        caller = stack[ index ]
+        filename = os.path.basename( caller[1] )
+        printFunc( 'File: %s:%d, Function: %s' % (filename, caller[2], caller[3]) )
+        del caller
+
+    del stack
+
+def checkTranslateUsage( msg ):
+    print( 'Error: T_(%r) called before translations are setup. Change to U_ or call after initTranslations.' % (msg,) )
+    _showCallers( 30, _print )
 
-def checkTranslate(msg):
-    print "Warning: Switch translation of <%s> to U_!" % msg
     return msg
 
-def noTranslate(msg):
+def checkPluralTranslateUsage( msg ):
+    print( 'Error: T_(%r) called before translations are setup. Change to U_ or call after initTranslations.' % (msg,) )
+    _showCallers( 30, _print )
+
+    return msg
+
+def noTranslate( msg ):
     return msg
 
 import __builtin__
-__builtin__.__dict__['T_'] = checkTranslate
+# defered translation
 __builtin__.__dict__['U_'] = noTranslate
+# translat text
+__builtin__.__dict__['T_'] = checkTranslateUsage
+# Plurals translation 
+__builtin__.__dict__['S_'] = checkPluralTranslateUsage
 
 import wb_frame
 import wb_preferences
@@ -69,6 +96,9 @@ class WbApp(wx.App):
         self.__debug = '--debug' in args
         self.__trace = '--trace' in args
 
+        # use test preferences
+        self.__test = '--test' in args
+
         self.__last_client_error = []
 
         self.args = args
@@ -77,42 +107,20 @@ class WbApp(wx.App):
         if self.app_dir == '':
             self.app_dir = startup_dir
 
+        self.translation = None
+        self.prefs = None
+        self._wx_locale = None
+
         self.main_thread = threading.currentThread()
 
         self.progress_format = None
         self.progress_values = {}
 
         wb_platform_specific.setupPlatform()
+        wb_shell_commands.setupCommands()
 
         self.setupLogging()
-        self.log.info( T_('Work Bench starting') )
-
-        # init the locale
-        self.initLocale()
-        self._setlocale_value = locale.getlocale()
-
-        if sys.platform == 'win32':
-            languages = [locale.getdefaultlocale()[0]]
-        else:
-            languages = [locale.getlocale()[0]]
-
-        locale_path = wb_platform_specific.getLocalePath( self )
-
-        all_mofiles = gettext.find( 
-                'pysvn_workbench',
-                locale_path,
-                languages,
-                all=1 )
-
-        self.translation = gettext.translation(
-                'pysvn_workbench',
-                locale_path,
-                languages,
-                fallback=True )
-
-        __builtin__.__dict__['T_'] = self.translation.ugettext
-        __builtin__.__dict__['S_'] = self.translation.ungettext
-        # U_ is defined above for pre translation markup
+        self.log.info( 'Work Bench starting' )
 
         # --project <dir> automatically creates a project entry for <dir>
         # if <dir> is a subversion working copy and no project entry exists for it.
@@ -122,28 +130,6 @@ class WbApp(wx.App):
             if project_arg_index < len( args ) - 1:
                self.auto_project_dir = os.path.abspath( os.path.join( startup_dir, args[ project_arg_index+1 ] ) )
 
-        # debug output for locale issue debugging
-        self.log.info( 'app_name %s' % (self.app_name,) )
-        self.log.info( 'app_dir %s' % (self.app_dir,) )
-        self.log.info( 'locale set to %r' % (locale.getlocale(),) )
-        self.log.info( 'locale_path %s' % (locale_path) )
-        self.log.info( 'languages %s' % (languages,) )
-        self.log.info( 'find %r' % (gettext.find( 'pysvn_workbench', locale_path, languages, all=1 ),) )
-        self.log.info( 'info %r' % (self.translation.info(),) )
-        self.log.info( 'main thread is %r' % (self.main_thread,) )
-
-        self.log.info( T_('PySVN WorkBench') )
-
-        if '--test' in args:
-            self.prefs = wb_preferences.Preferences(
-                    self,
-                    wb_platform_specific.getPreferencesFilename() + '.test',
-                    wb_platform_specific.getOldPreferencesFilename() + '.test' )
-        else:
-            self.prefs = wb_preferences.Preferences(
-                    self,
-                    wb_platform_specific.getPreferencesFilename(),
-                    wb_platform_specific.getOldPreferencesFilename() )
 
         self.lock_ui = 0
         self.need_activate_app_action = False
@@ -182,74 +168,104 @@ class WbApp(wx.App):
     # 2. Language and Text
     # 3. Drag lang to the top of the list
     # 4. look in ~/.CFUserTextEncoding
-    _all_mac_locales = {
-        '0:0':  'en_GB.utf-8',
-        '0:3':  'de_DE.utf-8',
-        '0:4':  'it_IT.utf-8',
+    _all_supported_mac_locales = {
+        (0, 0):         wx.LANGUAGE_ENGLISH_US,
+        (0, 2):         wx.LANGUAGE_ENGLISH_UK,
+        (0, 3):         wx.LANGUAGE_GERMAN,
+        (0, 4):         wx.LANGUAGE_ITALIAN,
+        (0x1D, 0x2B):   wx.LANGUAGE_HUNGARIAN,
         }
 
-    def initLocale( self ):
+    # just init the locale using wx.Locale. Use of python's locale module
+    # conflicts with wxPython and leads to all sorts of crashes or date failures
+    # like JDN problems on windows in history
+    #
+    # NOTE: wx.Locale needs wx.Application object to exist
+    #
+    def __initLocale( self ):
+        if self._wx_locale is not None:
+            return
+
         self.log.info( 'initLocale ----------------------------------------' )
         # init the locale
 
         if sys.platform == 'win32':
-            self.log.info( 'setlocale for windows' )
-            # on windows this will set to the default
-            locale.setlocale( locale.LC_ALL, '' )
-            return
+            self._wx_locale = wx.Locale( wx.LANGUAGE_DEFAULT, wx.LOCALE_LOAD_DEFAULT )
 
-        if sys.platform == 'darwin':
+        elif sys.platform == 'darwin':
             # on Mac this will set to the default
             # note: cannot find any docs on this to confirm its supported
             if '__CF_USER_TEXT_ENCODING' in os.environ:
-                self.log.info( 'setlocale from __CF_USER_TEXT_ENCODING %s' % os.environ['__CF_USER_TEXT_ENCODING'] )
-                lang_code = os.environ['__CF_USER_TEXT_ENCODING'].split( ':', 1 )[1]
-                locale.setlocale( locale.LC_ALL, self._all_mac_locales.get( lang_code, 'en_GB.utf-8' ) )
-                return
+                self.log.info( 'wx.setLocale from __CF_USER_TEXT_ENCODING %s' % os.environ['__CF_USER_TEXT_ENCODING'] )
+                # __CF_USER_TEXT_ENCODING may use 0x1f or 31 depending of OS X version
+                lang_code = [int( num, 0 ) for num in os.environ['__CF_USER_TEXT_ENCODING'].split( ':' )]
+                wx_lang_key = tuple( lang_code[1:3] )
+                if wx_lang_key not in self._all_supported_mac_locales:
+                    self.log.info( 'Unsupported langauge with code %r' % (wx_lang_key,) )
+                    wx_lang_code = wx.LANGUAGE_ENGLISH
+                else:
+                    wx_lang_code = self._all_supported_mac_locales[ wx_lang_key ]
 
-        # generic Posix locale code
-        if 'LC_ALL' in os.environ:
-            try:
-                self.log.info( 'setlocale from LC_ALL %s' % os.environ['LC_ALL'] )
-                locale.setlocale( locale.LC_ALL, os.environ['LC_ALL'] )
-                return
-
-            except locale.Error, e:
-                self.log.info( 'setlocale LC_ALL failed - %r' % (e,) )
-                pass
+                self.log.info( 'wx language code %d' % (wx_lang_code,) )
+                self._wx_locale = wx.Locale( wx_lang_code, wx.LOCALE_LOAD_DEFAULT )
 
+            else:
+                self._wx_locale = wx.Locale( wx.LANGUAGE_ENGLISH, wx.LOCALE_LOAD_DEFAULT )
         else:
-            self.log.info( 'LC_ALL is not set' )
-            for name in sorted( os.environ.keys() ):
-                self.log.info( 'Env %s=%s' % (name, os.environ[ name ]) )
+            # generic Posix locale code
+            self._wx_locale = wx.Locale( wx.LANGUAGE_DEFAULT, wx.LOCALE_LOAD_DEFAULT )
 
-        language_code, encoding = locale.getdefaultlocale()
-        self.log.info( 'getdefaultlocale -> %s, %s' % (language_code, encoding) )
-        if language_code is None:
-            language_code = 'en_US'
+        self.log.info( 'wx locale GetCanonicalName: %r' % (self._wx_locale.GetCanonicalName(),) )
 
-        if encoding is None:
-            encoding = 'UTF-8'
-        if encoding.lower() == 'utf':
-            encoding = 'UTF-8'
+    def initTranslations( self ):
+        self.__initLocale()
 
+        # only run once
+        if self.translation is not None:
+            return
 
-        try:
-            # setlocale fails when params it does not understand are passed
-            self.log.info( 'setlocale language_code, encoding -> %s, %s' % (language_code, encoding) )
-            locale.setlocale( locale.LC_ALL, '%s.%s' % (language_code, encoding) )
+        assert( self._wx_locale is not None )
 
-        except locale.Error, e:
-            self.log.info( 'setlocale language_code - %r' % (e,) )
+        self.log.info( 'Setting up translations' )
 
-            try:
-                # force a locale that will work
-                self.log.info( 'setlocale set to en_US.UTF-8' )
-                locale.setlocale( locale.LC_ALL, 'en_US.UTF-8' )
+        if sys.platform == 'win32':
+            languages = [locale.getdefaultlocale()[0]]
+        else:
+            languages = [locale.getlocale()[0]]
 
-            except locale.Error, e:
-                self.log.info( 'setlocale set to en_US.UTF-8 - %r' % (e,) )
-                locale.setlocale( locale.LC_ALL, 'C' )
+        locale_path = wb_platform_specific.getLocalePath( self )
+
+        all_mofiles = gettext.find( 
+                'pysvn_workbench',
+                locale_path,
+                languages,
+                all=1 )
+
+        self.translation = gettext.translation(
+                'pysvn_workbench',
+                locale_path,
+                languages,
+                fallback=True )
+
+        __builtin__.__dict__['T_'] = self.translation.ugettext
+        __builtin__.__dict__['S_'] = self.translation.ungettext
+        # U_ is defined above for pre translation markup
+
+        # debug output for locale issue debugging
+        self.log.info( 'app_name %s' % (self.app_name,) )
+        self.log.info( 'app_dir %s' % (self.app_dir,) )
+        self.log.info( 'main thread is %r' % (self.main_thread,) )
+        if sys.platform == 'win32':
+            self.log.info( 'locale set to %r' % (locale.getdefaultlocale(),) )
+        else:
+            self.log.info( 'locale set to %r' % (locale.getlocale(),) )
+        self.log.info( 'locale_path %s' % (locale_path) )
+        self.log.info( 'languages %s' % (languages,) )
+        self.log.info( 'find %r' % (gettext.find( 'pysvn_workbench', locale_path, languages, all=1 ),) )
+        for name in sorted( self.translation.info().keys() ):
+            self.log.info( 'translation info %s: %r' % (name, self.translation.info()[ name ]) )
+
+        self.log.info( 'Translations setup complete.' )
 
     def setupLogging( self ):
         self.log = logging.getLogger( 'WorkBench' )
@@ -483,6 +499,19 @@ class WbApp(wx.App):
         return True
 
     def OnInit(self):
+        self.initTranslations()
+
+        if self.__test:
+            self.prefs = wb_preferences.Preferences(
+                    self,
+                    wb_platform_specific.getPreferencesFilename() + '.test',
+                    wb_platform_specific.getOldPreferencesFilename() + '.test' )
+        else:
+            self.prefs = wb_preferences.Preferences(
+                    self,
+                    wb_platform_specific.getPreferencesFilename(),
+                    wb_platform_specific.getOldPreferencesFilename() )
+
         self.frame = wb_frame.WbFrame( self )
         self.frame.Show( True )
         self.SetTopWindow( self.frame )
@@ -515,20 +544,8 @@ class WbApp(wx.App):
                 (event.callback.__module__, event.callback.__name__ ) )
 
     def debugShowCallers( self, depth ):
-        if not self.__debug:
-            return
-
-        stack = inspect.stack()
-        for index in range( 1, depth+1 ):
-            if index >= len(stack):
-                break
-
-            caller = stack[ index ]
-            filename = os.path.basename( caller[1] )
-            self.log.debug( 'File: %s:%d, Function: %s' % (filename, caller[2], caller[3]) )
-            del caller
-
-        del stack
+        if self.__debug:
+            _showCallers( depth, self.log.debug )
 
 class AppBackgroundFunction:
     def __init__( self, app, function, args ):
