@@ -11,18 +11,23 @@
 
 '''
 import threading
+import locale
 
 class BackgroundThread(threading.Thread):
-    def __init__( self ):
+    def __init__( self, app ):
         threading.Thread.__init__( self )
+
         self.setDaemon( 1 )
         self.running = 1
+        self.app = app
 
         self.work_queue = []
         self.queue_lock = threading.Lock()
         self.queued_work_semaphore = threading.Semaphore( 0 )
 
     def run( self ):
+        self.app.log.info( 'BackgroundThread thread %r' % (threading.currentThread(),) )
+        self.app.log.info( 'BackgroundThread locale %r' % (locale.getlocale(),) )
         while self.running:
             # wait for work
             self.queued_work_semaphore.acquire()
@@ -35,8 +40,6 @@ class BackgroundThread(threading.Thread):
             # run the function
             function()
 
-        print 'BackgroundThread.run() shutdown'
-
     def addWork( self, function ):
         # queue the function
         self.queue_lock.acquire()
