@@ -10,7 +10,6 @@
     wb_diff_frame.py
 
 '''
-import threading
 import wx
 import wx.stc
 
@@ -47,12 +46,12 @@ class DiffFrame(wx.Frame):
         if diff_prefs.maximized:
             extra_style = wx.MAXIMIZE
 
-        wx.Frame.__init__(self, None, -1, T_("Diff %(title1)s and %(title2)s") %
-                            {'title1': title_left
-                            ,'title2': title_right},
-                diff_prefs.frame_position,
-                diff_prefs.getFrameSize(),
-                wx.DEFAULT_FRAME_STYLE|extra_style )
+        wx.Frame.__init__( self, None, -1, T_("Diff %(title1)s and %(title2)s") %
+                                {'title1': title_left
+                                ,'title2': title_right},
+                            diff_prefs.frame_position,
+                            diff_prefs.getFrameSize(),
+                            wx.DEFAULT_FRAME_STYLE|extra_style )
 
         # Reset the size after startup to workaround a potential
         # problem on OSX with incorrect first size event saving the
@@ -81,13 +80,17 @@ class DiffFrame(wx.Frame):
         s = self.CreateStatusBar()
 
         s.SetFieldsCount( 3 )
-        s.SetStatusWidths( [-1, 380, 10] )
+        s.SetStatusWidths( [-1,  -1, 480] )
+
+        s.SetStatusText( 'Ready', 0 )
+        s.SetStatusText( 'Steady', 1 )
+        s.SetStatusText( 'Go!', 2 )
 
         self.total_change_number = 0
         self.current_change_number = 0
         self.setChangeCounts( 0, 0 )
 
-        self.status_bar_key_field = DiffBodyText( s )
+        self.status_bar_key_field = DiffBodyText( s, line_numbers=False )
         self.status_bar_key_field.InsertStyledText( T_('Key: '), self.status_bar_key_field.style_line_normal )
         self.status_bar_key_field.InsertStyledText( T_('Inserted text '), self.status_bar_key_field.style_line_insert )
         self.status_bar_key_field.InsertStyledText( T_('Deleted text '), self.status_bar_key_field.style_line_delete )
@@ -101,7 +104,12 @@ class DiffFrame(wx.Frame):
         wx.EVT_IDLE( s, self.OnStatusBarIdle )
 
         # Set up the splitter window with the editor panels
-        self.splitter = wx.SplitterWindow( self, -1 )
+        if 'wxMac' in wx.PlatformInfo:
+            style = wx.SP_LIVE_UPDATE | wx.SP_3DSASH
+        else:
+            style = wx.SP_LIVE_UPDATE
+
+        self.splitter = wx.SplitterWindow( self, -1, style=style )
         self.sash_ratio = 0.5
 
         self.panel_left = DiffPanel( self.splitter, title_left )
@@ -118,12 +126,11 @@ class DiffFrame(wx.Frame):
         self.processor = wb_diff_processor.DiffProcessor( self.panel_left.ed, self.panel_right.ed )
         self.diff = wb_diff_difflib.Difference( self.processor )
 
-
         self.files_ok = self.diff.filecompare( file_left, file_right )
         if not self.files_ok:
             return
 
-        self.setChangeCounts( None, self.processor.getChangeCount() )
+        self.setChangeCounts( 0, self.processor.getChangeCount() )
         self.SetZoom( diff_prefs.zoom )
 
         # Move to the first change in the editor.
@@ -157,7 +164,6 @@ class DiffFrame(wx.Frame):
         wx.stc.EVT_STC_ZOOM( self, self.panel_left.ed.GetId(), self.OnZoomChange )
         wx.stc.EVT_STC_ZOOM( self, self.panel_right.ed.GetId(), self.OnZoomChange )
 
-
     def isOk( self ):
         return self.files_ok
 
@@ -179,14 +185,17 @@ class DiffFrame(wx.Frame):
         if total_change_number is not None:
             self.total_change_number = total_change_number
 
-        self.SetStatusText( T_('Diff %(change1)d of %(change2)d') %
+        self.GetStatusBar().SetStatusText( T_('Diff %(change1)d of %(change2)d') %
                                 {'change1': self.current_change_number
-                                ,'change2': self.total_change_number}, 2 )
+                                ,'change2': self.total_change_number}, 1 )
 
     def _repositionStatusBar(self):
-        rect = self.GetStatusBar().GetFieldRect( 1 )
-        self.status_bar_key_field.SetPosition(wx.Point(rect.x+2, rect.y+2))
-        self.status_bar_key_field.SetSize(wx.Size(rect.width-4, rect.height-4))
+        rect = self.GetStatusBar().GetFieldRect( 2 )
+        rect.x += 1
+        rect.y += 1
+        rect.width += 4
+        rect.height += 4
+        self.status_bar_key_field.SetRect( rect )
 
     #------------------------------------------------------------
     def OnCloseWindow( self, event ):
@@ -276,11 +285,11 @@ def WB_EVT_SYNC_SCROLL( window, id, handler ):
 
 class SyncScrollEvent(wx.PyCommandEvent):
     'SyncScrollEvent'
-    def __init__(self, id, text_body_this, test_body_other):
+    def __init__(self, id, text_body_this, text_body_other):
         wx.PyCommandEvent.__init__(self, WB_EVT_SYNC_SCROLL_type, id)
 
         self.text_body_this = text_body_this
-        self.test_body_other = test_body_other
+        self.text_body_other = text_body_other
 
 #----------------------------------------------------------------------
 
@@ -289,20 +298,16 @@ class DiffPanel(wx.Panel):
     def __init__( self, parent_win, title ):
         wx.Panel.__init__( self, parent_win, -1 )
 
-        self.SetSize(wx.Size(200, 200))
+        self.SetSize( wx.Size(200, 200) )
 
         self.text_file_name = wx.TextCtrl(self, -1, title,
                         wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY )
 
         self.ed = DiffBodyText( self )
 
-
-        box_diffs = wx.BoxSizer( wx.VERTICAL )
-        box_diffs.Add( self.ed, 1, wx.EXPAND )
-
         box_line_numbers = wx.BoxSizer( wx.HORIZONTAL )
         box_line_numbers.Add( self.ed.diff_line_numbers, 0, wx.EXPAND )
-        box_line_numbers.Add( box_diffs, 1, wx.EXPAND )
+        box_line_numbers.Add( self.ed, 1, wx.EXPAND )
 
         box_file_name = wx.BoxSizer( wx.VERTICAL )
         box_file_name.Add( self.text_file_name, 0, wx.EXPAND )
@@ -315,32 +320,16 @@ class DiffPanel(wx.Panel):
 
 #------------------------------------------------------------------------------------------
 class DiffBodyText(wx.stc.StyledTextCtrl):
-    def __init__(self, parent):
+    def __init__( self, parent, line_numbers=True ):
 
-        self.test_body_other = None
+        self.text_body_other = None
 
-        wx.stc.StyledTextCtrl.__init__(self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER)
+        wx.stc.StyledTextCtrl.__init__( self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER )
 
-        self.diff_line_numbers = DiffLineNumbers( parent )
-
-        # Calculate space for 5 digits
-        font = wx.Font(point_size, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False, face)
-        width, _, _, _ = self.diff_line_numbers.GetFullTextExtent('12345', font)
-
-        width = width + 10
-        self.diff_line_numbers.SetSize( wx.Size( width, 200 ) )
-        # starting with 2.5.2.? we have to set the hint
-        self.diff_line_numbers.SetSizeHints( minW=width, maxW=width, maxH=-1, minH=-1 )
-        self.diff_line_numbers.Enable( False )
-
-        # Hide the scrollbars for the line number edit control
-        scrollbar = wx.ScrollBar( self, -1, style = wx.SB_VERTICAL )
-        self.diff_line_numbers.SetVScrollBar( scrollbar )
-        scrollbar.Show( False )
-        self.diff_line_numbers.SetUseHorizontalScrollBar( False )
-
-        self.diff_line_numbers.StyleSetSpec( wx.stc.STC_STYLE_DEFAULT,
-                "size:%d,face:%s,fore:#000000,back:#e0e0e0" % (point_size, face) )
+        if line_numbers:
+            self.diff_line_numbers = DiffLineNumbers( parent )
+        else:
+            self.diff_line_numbers = None
 
         self.fold_margin = -1
         self.fold_start = -1
@@ -382,11 +371,11 @@ class DiffBodyText(wx.stc.StyledTextCtrl):
 
         wx.stc.EVT_STC_MARGINCLICK( self, -1, self.OnMarginClick )
 
-        self.SetupFolding( 1 )
+        if line_numbers:
+            self.SetupFolding( 1 )
 
         wx.EVT_MOUSEWHEEL( self, self.OnMouseWheel )
         wx.EVT_SCROLLWIN( self, self.OnNeedToSyncScroll )
-        wx.stc.EVT_STC_UPDATEUI( self, -1, self.OnNeedToSyncScroll )
         WB_EVT_SYNC_SCROLL( self, -1, self.OnSyncScroll )
         DiffBodyText.body_count += 1
         self.body_count = DiffBodyText.body_count
@@ -396,30 +385,30 @@ class DiffBodyText(wx.stc.StyledTextCtrl):
         return '<DiffBodyText: %d>' % self.body_count
 
     def OnMouseWheel( self, event ):
-        assert( self.test_body_other )
-        self.GetEventHandler().AddPendingEvent( SyncScrollEvent( self.GetId(), self, self.test_body_other ) )
+        assert( self.text_body_other )
+        self.GetEventHandler().AddPendingEvent( SyncScrollEvent( self.GetId(), self, self.text_body_other ) )
         event.Skip()
 
     def OnNeedToSyncScroll( self, event ):
-        if self.test_body_other is not None:
-            
-            self.GetEventHandler().AddPendingEvent( SyncScrollEvent( self.GetId(), self, self.test_body_other ) )
+        if self.text_body_other is not None:
+            self.GetEventHandler().AddPendingEvent( SyncScrollEvent( self.GetId(), self, self.text_body_other ) )
+
         event.Skip()
 
     def OnSyncScroll( self, event ):
         line_number = event.text_body_this.GetFirstVisibleLine()
-        event.test_body_other.ScrollToLine( line_number )
-        event.test_body_other.diff_line_numbers.ScrollToLine( line_number )
+        event.text_body_other.ScrollToLine( line_number )
+        event.text_body_other.diff_line_numbers.ScrollToLine( line_number )
         event.text_body_this.diff_line_numbers.ScrollToLine( line_number )
         
         xpos = event.text_body_this.GetXOffset()
-        event.test_body_other.SetXOffset( xpos )
+        event.text_body_other.SetXOffset( xpos )
         sb_horizontal_postion = event.text_body_this.GetScrollPos( wx.SB_HORIZONTAL )
-        if event.test_body_other.GetScrollPos( wx.SB_HORIZONTAL ) != sb_horizontal_postion:
-            event.test_body_other.SetScrollPos( wx.SB_HORIZONTAL, sb_horizontal_postion, True )
+        if event.text_body_other.GetScrollPos( wx.SB_HORIZONTAL ) != sb_horizontal_postion:
+            event.text_body_other.SetScrollPos( wx.SB_HORIZONTAL, sb_horizontal_postion, True )
 
-    def SetMirrorEditor( self, test_body_other ):
-        self.test_body_other = test_body_other
+    def SetMirrorEditor( self, text_body_other ):
+        self.text_body_other = text_body_other
 
     def ToggleViewWhiteSpace( self ):
         if self.GetViewWhiteSpace():
@@ -525,34 +514,51 @@ class DiffBodyText(wx.stc.StyledTextCtrl):
         for line in range(self.GetLineCount()):
             if( self.GetFoldLevel( line ) & wx.stc.STC_FOLDLEVELHEADERFLAG
             and ((self.GetFoldExpanded( line ) and not show_folds)
-            or (not self.GetFoldExpanded( line ) and show_folds)) ):
+                or (not self.GetFoldExpanded( line ) and show_folds)) ):
                 self.ToggleFoldAtLine( line )
 
 #------------------------------------------------------------------------------------------
 class DiffLineNumbers(wx.stc.StyledTextCtrl):
-    def __init__(self, parent):
+    def __init__( self, parent ):
 
-        wx.stc.StyledTextCtrl.__init__(self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER)
+        wx.stc.StyledTextCtrl.__init__( self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER )
 
         self.style_line_numbers = 0
         self.style_line_numbers_for_diff = 1
 
         self.EmptyUndoBuffer()
 
-        self.SetMarginWidth(0, 0)
-        self.SetMarginWidth(1, 0)
-        self.SetMarginWidth(2, 0)
+        self.SetMarginWidth( 0, 0 )
+        self.SetMarginWidth( 1, 0 )
+        self.SetMarginWidth( 2, 0 )
 
-        self.SetScrollWidth(10000)
+        self.SetScrollWidth( 10000 )
 
         # make some styles
         self.StyleSetSpec( wx.stc.STC_STYLE_DEFAULT,
-                "size:%d,face:%s,fore:#000000" % (point_size, face) )
+                "size:%d,face:%s,fore:#000000,back:#e0e0e0" % (point_size, face) )
         self.StyleSetSpec( self.style_line_numbers,
                 "size:%d,face:%s,fore:#000000,back:#f0f0f0" % (point_size, face) )
         self.StyleSetSpec( self.style_line_numbers_for_diff,
                 "size:%d,face:%s,fore:#000000,back:#d0d0d0" % (point_size, face) )
 
+        # Calculate space for 5 digits
+        font = wx.Font( point_size, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False, face )
+        width, _, _, _ = self.GetFullTextExtent( '12345', font )
+
+        width = width + 10
+        self.SetSize( wx.Size( width, 200 ) )
+        # starting with 2.5.2.? we have to set the hint
+        self.SetSizeHints( minW=width, maxW=width, maxH=-1, minH=-1 )
+        self.Enable( False )
+
+        # Hide the scrollbars for the line number edit control
+        self.scrollbar = wx.ScrollBar( self, -1, style = wx.SB_VERTICAL )
+        self.SetVScrollBar( self.scrollbar )
+        self.scrollbar.Show( False )
+        self.SetUseHorizontalScrollBar( False )
+
+
     #--------------------------------------------------------------------------------
     def InsertStyledText( self, text, style ):
         pos = self.GetLength()
