@@ -774,7 +774,7 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpAdd( self, event ):
         self.getUpdateUiState()
-        event.Enable( self.ui_state_focus.unversioned and self.ui_state_focus.file_exists )
+        event.Enable( self.ui_state_focus.unversioned and (self.ui_state_focus.is_folder or self.ui_state_focus.file_exists) )
 
     def OnSpAnnotate( self, event ):
         return self.Sp_Dispatch( 'OnSpAnnotate' )
@@ -808,10 +808,8 @@ class WbFrame(wx.Frame):
     def OnUpdateUiSpCheckout( self, event ):
         self.getUpdateUiState()
 
-        # this is a tree only command
         event.Enable( self.ui_state_tree.is_project_parent
-                        and not self.ui_state_tree.file_exists
-                        and self.ui_state_tree.versioned )
+                        and self.ui_state_focus.need_checkout )
 
     def OnSpCheckoutTo( self, event ):
         self.clearUpdateUiState()
@@ -1093,13 +1091,13 @@ class WbFrame(wx.Frame):
             self.ui_state_tree = self.tree_panel.getUpdateUiState()
             if self.ui_state_tree is None:
                 self.ui_state_tree = wb_tree_panel.TreeState( None, True )
-            all_debug_messages.append( 'tree place_holder %s' % self.ui_state_tree.place_holder )
+            all_debug_messages.append( 'tree place_holder %s' % (self.ui_state_tree.place_holder,) )
 
         if self.ui_state_list is None:
             self.ui_state_list = self.list_panel.getUpdateUiState()
             if self.ui_state_list is None:
                 self.ui_state_list = wb_list_panel_common.ListItemState( None, True )
-            all_debug_messages.append( 'list place_holder %s' % self.ui_state_list.place_holder )
+            all_debug_messages.append( 'list place_holder %s' % (self.ui_state_list.place_holder,) )
 
         if self.ui_state_focus is None:
             if self.event_handler is None:
@@ -1118,7 +1116,7 @@ class WbFrame(wx.Frame):
         if wb_config.debug_selection and len(all_debug_messages)>0:
             print 'ZF: getUpdateUiState() ------------------------------'
             for message in all_debug_messages:
-                print '    %s' %message
+                print '    %s' % (message,)
 
     def clearUpdateUiState( self ):
         if wb_config.debug_selection: print 'ZF: clearUpdateUiState()'
