@@ -17,7 +17,10 @@ import os
 import string
 import subprocess
 import wb_platform_specific
+import tempfile
 
+def setupCommands():
+    pass
 
 def getTerminalProgramList():
     return ['CMD']
@@ -71,8 +74,6 @@ def ShellOpen( app, project_info, filename ):
                             ,'error': e[2]} )
 
 def CommandShell( app, project_info ):
-    shell_script_filename = os.path.join( os.environ['TEMP'], 'wb_shell_tmp.cmd' )
-
     p = app.prefs.getShell()
     working_dir = project_info.getWorkingDir()
 
@@ -92,12 +93,13 @@ def CommandShell( app, project_info ):
     if len( p.shell_init_command ) > 0:
         cmd_lines.append( u'call %s\n' % (p.shell_init_command,) )
 
-    f  = open( shell_script_filename, 'w' )
+    f = tempfile.NamedTemporaryFile( mode='w', delete=False, prefix='tmp-wb-shell', suffix='.cmd' )
+    app.all_temp_files.append( f.name )
     for line in cmd_lines:
         f.write( line.encode( 'utf-8' ) )
     f.close()
 
-    command_line = u'"%s" /k %s' % (os.environ['ComSpec'], shell_script_filename)
+    command_line = u'"%s" /k "%s"' % (os.environ['ComSpec'], f.name)
 
     app.log.info( command_line )
     CreateProcess( app, command_line, working_dir )
@@ -115,9 +117,15 @@ def CreateProcess( app, command_line, current_dir ):
         return
 
     try:
+        import ctypes
+        old_value = ctypes.c_long( 0 )
+        try:
+            ctypes.windll.kernel32.Wow64DisableWow64FsRedirection( ctypes.byref( old_value ) )
+        except:
+            pass
+
         si = win32process.STARTUPINFO()
-        h_process, h_thread, process_id, thread_id = win32process.CreateProcess\
-            (
+        h_process, h_thread, process_id, thread_id = win32process.CreateProcess(
             None,
             command_line,
             None,               # processAttributes
@@ -128,6 +136,13 @@ def CreateProcess( app, command_line, current_dir ):
             current_dir,        # currentDirectory ,
             si                  # startupinfo
             )
+
+        try:
+            ctypes.windll.kernel32.Wow64RevertWow64FsRedirection( old_value )
+        except:
+            pass
+
+
     except win32process.error, detail:
         app.log.error( T_('Create process failed for command - %(command)s\n'
                         'Reason %(reason)s') %
