@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -17,6 +17,7 @@ import wx.calendar
 import os
 import time
 import types
+import urllib
 
 import pysvn
 
@@ -53,7 +54,10 @@ class LogEntry:
         self.author = author
         self.date = date
         self.label = label
-        self.message = message
+        try:
+            self.message = message.decode( 'utf-8' )
+        except ValueError:
+            self.message = message
         self.changed_paths = changed_paths
 
         self.changed_paths.sort( self.by_changed_path )
@@ -70,19 +74,27 @@ class LogEntry:
 
         if filter_field == T_('Author'):
             return filter_text.lower() in self.author.lower()
+
         elif filter_field == T_('Comment'):
             return filter_text.lower() in self.message.lower()
+
         elif filter_field == T_('Path'):
             for changed_path in self.changed_paths:
-                if filter_text.lower() in changed_path.path.lower():
+                try:
+                    c_p_p = changed_path.path.decode('utf-8')
+                except ValueError:
+                    c_p_p = changed_path.path
+
+                if filter_text.lower() in c_p_p.lower():
                     return True
 
             return False
+
         else:
             assert( False )
             return False
 
-def getHistoryEntries( project_info, filename, limit, revision_end, include_tags ):
+def getHistoryEntries( project_info, filename, limit, revision_end, include_tags, revision_start ):
     all_history_entries = []
     # need the URL and repos_root_URL
     # [0] first entry [0][1] the info
@@ -91,17 +103,19 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
         info = project_info.client_bg.info2( info.URL, recurse=False )[0][1]
 
     all_log_entries = project_info.client_bg.log(
-                    filename,
-                    strict_node_history=False,
-                    discover_changed_paths=True,
-                    limit=limit,
-                    revision_end=revision_end )
+                        filename,
+                        strict_node_history=False,
+                        discover_changed_paths=True,
+                        limit=limit,
+                        revision_start=revision_start,
+                        revision_end=revision_end )
 
     # Settings an end date can lead to no entries
     if len( all_log_entries ) == 0:
         return info.URL, all_history_entries
 
-    repos_path = info.URL[len(info.repos_root_URL):]
+    repos_path = urllib.unquote( info.URL[len(info.repos_root_URL):].encode( 'utf-8' ) )
+
     for log in all_log_entries:
         # author is optional
         if 'author' not in log:
@@ -110,7 +124,7 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
         all_history_entries.append(
             LogEntry(
                 log.revision.number,
-                info.repos_root_URL+repos_path,
+                info.URL,
                 log.author,
                 log.date,
                 '',
@@ -119,7 +133,11 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
 
         for changed_path in log.changed_paths:
             if changed_path.action in ['A','M']:
-                if repos_path == changed_path.path:
+                if changed_path.path is not None:
+                    c_p_p = changed_path.path.decode( 'utf-8' )
+                else:
+                    c_p_p = None
+                if repos_path == c_p_p:
                     if changed_path.copyfrom_path is not None:
                         repos_path = changed_path.copyfrom_path
                     break
@@ -190,6 +208,7 @@ class LogHistoryDialog(wx.Dialog):
         is_show_all = p.default_mode == 'show_all'
         is_show_limit = p.default_mode == 'show_limit'
         is_show_since = p.default_mode == 'show_since'
+        is_show_range = p.default_mode == 'show_range'
 
         self.all_radio = wx.RadioButton( self, -1, T_('Show all entries') )
         self.all_radio.SetValue( is_show_all )
@@ -199,7 +218,7 @@ class LogHistoryDialog(wx.Dialog):
 
         self.limit_radio = wx.RadioButton( self, -1, T_('Show only:') )
         self.limit_radio.SetValue( is_show_limit )
-        self.limit_text = wx.TextCtrl( self, -1, str(p.default_limit), style=wx.TE_RIGHT )
+        self.limit_text = wx.TextCtrl( self, -1, str(p.default_limit) )
         self.limit_text.Enable( is_show_limit )
 
         self.g_sizer.Add( self.limit_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
@@ -218,6 +237,18 @@ class LogHistoryDialog(wx.Dialog):
         self.g_sizer.Add( self.since_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_TOP, 3 )
         self.g_sizer.Add( self.since_date, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
+        self.range_radio = wx.RadioButton( self, -1, T_('Show range:') )
+        self.range_radio.SetValue( is_show_range )
+        self.range_start_text = wx.TextCtrl( self, -1, 'head' )
+        self.range_start_text.Enable( is_show_range )
+        self.range_end_text = wx.TextCtrl( self, -1, '1' )
+        self.range_end_text.Enable( is_show_range )
+
+        self.g_sizer.Add( self.range_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.range_start_text, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( (0,0), 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.range_end_text, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
         self.tags_label = wx.StaticText( self, -1, T_('Include tags: '), style=wx.ALIGN_RIGHT)
         self.tags_ctrl = wx.CheckBox( self, -1, T_('Include tags in log history') )
         self.tags_ctrl.SetValue( p.default_include_tags )
@@ -251,6 +282,7 @@ class LogHistoryDialog(wx.Dialog):
         wx.EVT_RADIOBUTTON( self, self.all_radio.GetId(), self.OnRadio )
         wx.EVT_RADIOBUTTON( self, self.limit_radio.GetId(), self.OnRadio )
         wx.EVT_RADIOBUTTON( self, self.since_radio.GetId(), self.OnRadio )
+        wx.EVT_RADIOBUTTON( self, self.range_radio.GetId(), self.OnRadio )
 
         wx.calendar.EVT_CALENDAR_SEL_CHANGED( self, self.since_date.GetId(), self.OnCalendarSelChanged )
 
@@ -265,6 +297,8 @@ class LogHistoryDialog(wx.Dialog):
     def OnRadio( self, event ):
         self.since_date.Enable( self.since_radio.GetValue() )
         self.limit_text.Enable( self.limit_radio.GetValue() )
+        self.range_end_text.Enable( self.range_radio.GetValue() )
+        self.range_start_text.Enable( self.range_radio.GetValue() )
 
     def OnCalendarSelChanged( self, event ):
         if self.since_radio.GetValue():
@@ -301,9 +335,36 @@ class LogHistoryDialog(wx.Dialog):
         if self.since_radio.GetValue():
             date = self.since_date.GetDate()
             return pysvn.Revision( pysvn.opt_revision_kind.date, date.GetTicks() )
+
+        elif self.range_radio.GetValue():
+            try:
+                rev = self.range_end_text.GetValue().strip()
+                if rev == '':
+                    return pysvn.Revision( pysvn.opt_revision_kind.number, 0 )
+
+                return pysvn.Revision( pysvn.opt_revision_kind.number, int( rev ) )
+
+            except ValueError:
+                return pysvn.Revision( pysvn.opt_revision_kind.number, 0 )
+
         else:
             return pysvn.Revision( pysvn.opt_revision_kind.number, 0 )
 
+    def getRevisionStart( self ):
+        try:
+            if self.range_radio.GetValue():
+                rev = self.range_start_text.GetValue().strip()
+                if rev == '':
+                    return pysvn.Revision( pysvn.opt_revision_kind.head )
+
+                return pysvn.Revision( pysvn.opt_revision_kind.number, int( rev ) )
+
+            else:
+                return pysvn.Revision( pysvn.opt_revision_kind.head )
+
+        except ValueError:
+            return pysvn.Revision( pysvn.opt_revision_kind.head )
+
     def getIncludeTags( self ):
         return self.tags_ctrl.GetValue()
 
@@ -484,7 +545,7 @@ class LogHistoryPanel:
         # Arrange the panels with the splitter windows
         self.splitter.AppendWindow( self.panel_history, 250 )
         self.splitter.AppendWindow( self.panel_comment, 100 )
-        self.splitter.AppendWindow( self.panel_changed_paths, 150 )
+        self.splitter.AppendWindow( self.panel_changed_paths, 200 )
 
         self.selected_revisions = {}
 
@@ -508,7 +569,7 @@ class LogHistoryPanel:
         char_width = 9
         self.list_ctrl.SetColumnWidth( self.col_revision, 7*char_width )
         self.list_ctrl.SetColumnWidth( self.col_author, 14*char_width )
-        self.list_ctrl.SetColumnWidth( self.col_date, 15*char_width )
+        self.list_ctrl.SetColumnWidth( self.col_date, 18*char_width )
         self.list_ctrl.SetColumnWidth( self.col_label, 12*char_width )
         self.list_ctrl.SetColumnWidth( self.col_message, 40*char_width )
 
@@ -525,9 +586,9 @@ class LogHistoryPanel:
 
         char_width = 9
         self.paths_ctrl.SetColumnWidth( self.col_action, 7*char_width )
-        self.paths_ctrl.SetColumnWidth( self.col_path, 40*char_width )
+        self.paths_ctrl.SetColumnWidth( self.col_path, 60*char_width )
         self.paths_ctrl.SetColumnWidth( self.col_copyfrom_revision, 6*char_width )
-        self.paths_ctrl.SetColumnWidth( self.col_copyfrom_path, 40*char_width )
+        self.paths_ctrl.SetColumnWidth( self.col_copyfrom_path, 60*char_width )
 
         self.initButtons( self.v_sizer_history )
 
@@ -686,7 +747,7 @@ class LogHistoryPanel:
             self.paths_ctrl.InsertStringItem( index,
                 action_map.get( info.action, info.action ) )
             self.paths_ctrl.SetStringItem( index, self.col_path,
-                info.path )
+                info.path.decode( 'utf-8' ) )
             if info.copyfrom_path is not None:
                 self.paths_ctrl.SetStringItem( index, self.col_copyfrom_revision,
                     str( info.copyfrom_revision.number ) )
