@@ -211,12 +211,22 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         self.app.clearProgress()
         self.app.refreshFrame()
 
-
     #------------------------------------------------------------
     def Cmd_File_Add( self, all_rows ):
+        # handles both files and folders
         try:
             for filename in [self.getFilename( row ) for row in all_rows]:
-                self.project_info.client_fg.add( filename )
+                if wb_platform_specific.uPathIsdir( filename ):
+                    name = os.path.basename( filename )
+                    force, recursive = self.app.addFolder( T_('Add Folder'), name, force=False, recursive=True )
+                    if force is None:
+                        continue
+
+                    self.project_info.client_fg.add( filename, force=force, recurse=recursive )
+
+                else:
+                    self.project_info.client_fg.add( filename )
+
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
