@@ -12,7 +12,6 @@
 '''
 import os
 import types
-import threading
 import locale
 
 import pysvn
@@ -172,8 +171,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     def updateStatus( self ):
         try:
             self.project_info.updateStatus()
+
         except pysvn.ClientError, e:
-            print 'Error: %s' % e.args[0]
+            print 'Error: %s' % (e.args[0],)
 
     def getBackgroundColour( self ):
         return (255,255,255)
@@ -181,7 +181,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     def getBranchOriginRevision( self ):
         if self.__branch_origin_revision is None:
             try:
-                log_entries = self.project_info.client_bg.log(self.project_info.url, discover_changed_paths=True)
+                log_entries = self.project_info.client_bg.log( self.project_info.url, discover_changed_paths=True )
+
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
                 return None
@@ -192,7 +193,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             # If the oldest revision has a copyfrom_path, this is a branch,
             # so we set __branch_origin_url, __branch_url and __branch_origin_revision.
             if changed_paths['copyfrom_path'] is not None:
-                base_url = '/'.join(self.project_info.url.split('/')[:4])
+                base_url = self.client_bg.info2( self.project_info.url )[0][1]['repos_root_URL']
                 self.__branch_origin_url = base_url + changed_paths['copyfrom_path']
                 self.__branch_url = base_url + changed_paths['path']
                 self.__branch_origin_revision = changed_paths['copyfrom_revision']
@@ -383,7 +384,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                 if self.isProjectParent():
                     return T_('Use the Checkout command to fetch files')
                 else:
-                    return T_('Use the Update command to fetch files')
+                    return T_('Use Add command to add this folder to the working copy')
             else:
                 return ''
 
@@ -516,8 +517,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if status.entry is None or status.entry.commit_time == 0:
             return ''
         else:
-            # should not need to force the locale!
-            locale.setlocale( locale.LC_ALL, self.app._setlocale_value )
+            #qqq# should not need to force the locale!
+            #qqq# locale.setlocale( locale.LC_ALL, self.app._setlocale_value )
             return wb_subversion_utils.fmtDateTime( status.entry.commit_time )
 
     def __get_LockCommentColumn( self, status ):
@@ -823,6 +824,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
         if branch_url is None:
             wx.MessageBox( T_('"%s" is not a branch.') % self.project_info.url, T_("Error"), style=wx.OK|wx.ICON_ERROR )
+
         else:
             branch_origin_url = self.getBranchOriginUrl()
 
@@ -927,7 +929,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                             filename,
                             dialog.getLimit(),
                             dialog.getRevisionEnd(),
-                            dialog.getIncludeTags() )
+                            dialog.getIncludeTags(),
+                            dialog.getRevisionStart() )
                 ok = True
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
