@@ -60,7 +60,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         self.notification_of_files_in_conflict = 0
 
     def __repr__( self ):
-        return '<svn.ProjectInfo wc_path=%r>' % self.wc_path
+        return '<svn.ProjectInfo wc_path=%r>' % (self.wc_path,)
         #return '<wb_subversion_provider.ProjectInfo url=%s, wc_path=%s>' % (self.url, self.wc_path)
 
     def init( self, project_name, **kws):
@@ -270,6 +270,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
 
         self.need_checkout = True
         if not wb_platform_specific.uPathExists( self.wc_path ):
+            self.app.log.debug( 'updateStatus() wc_path does not exist' )
             return
 
         p = self.app.prefs.getView()
@@ -279,6 +280,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             entry = self.client_fg.info2( self.wc_path, recurse=False )[0][1]
 
         except pysvn.ClientError, e:
+            self.app.log.debug( 'updateStatus() info2 exception %r' % (e,) )
             if wb_subversion_utils.version_info.has_upgrade:
                 # is it the  'Working copy XXX is too old' error?
                 if e.args[1][0][1] == pysvn.svn_err.wc_upgrade_required:
