@@ -124,10 +124,10 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             state.debug_msg = 'no dir status'
             state.modified = False
             state.new_versioned = False
-            state.versioned = True
-            state.unversioned = False
+            state.versioned = False
+            state.unversioned = True
             state.need_checkin = False
-            state.need_checkout = True
+            state.need_checkout = self.is_project_parent
             state.need_upgrade = False
             state.conflict = False
             state.file_exists = False
@@ -174,6 +174,8 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
             state.revertable = state.conflict or state.modified or state.need_checkin or not state.file_exists
 
+        state.debugPrintState( self.app.log.debug, 'SubversionProject.getState()' )
+
         return state
 
     def getContextMenu( self, state ):
@@ -477,7 +479,8 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                         filename,
                         dialog.getLimit(),
                         dialog.getRevisionEnd(),
-                        dialog.getIncludeTags() )
+                        dialog.getIncludeTags(),
+                        dialog.getRevisionStart() )
             ok = True
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
