@@ -338,26 +338,32 @@ class WbTreePanel(wx.Panel):
         pi = bm.getBookmark( bookmark_name )
         self.gotoProjectInfo( pi )
 
-    def gotoProjectInfo( self, pi ):
-        parent_item = self.tree_ctrl.GetRootItem()
-
+    def __findInTree( self, pi, parent_item ):
         child_item, cookie = self.tree_ctrl.GetFirstChild( parent_item )
         while child_item:
             tree_pi = self.tree_ctrl.GetPyData( child_item ).getProjectInfo()
             if tree_pi.isEqual( pi ):
                 # found it
-                break
+                return child_item
 
             if tree_pi.isChild( pi ):
                 # drill deeper
                 self.tree_ctrl.Expand( child_item )
                 # child becomes parent at next level
-                parent_item = child_item
-                child_item, cookie = self.tree_ctrl.GetFirstChild( parent_item )
-            else:
-                # keep looking at this level
-                child_item, cookie = self.tree_ctrl.GetNextChild( parent_item, cookie )
+                found_item = self.__findInTree( pi, child_item )
+                if found_item:
+                    return found_item
 
+                # do not leave the tree expanded on nodes that did not hold the answer
+                self.tree_ctrl.Collapse( child_item )
+
+            # keep looking at this level
+            child_item, cookie = self.tree_ctrl.GetNextChild( parent_item, cookie )
+
+        return None
+
+    def gotoProjectInfo( self, pi ):
+        child_item = self.__findInTree( pi, self.tree_ctrl.GetRootItem() )
         if child_item:
             self.tree_ctrl.SelectItem( child_item )
             self.tree_ctrl.EnsureVisible( child_item )
